pub fn set_command_timeout(timeout: Option<Duration>)Expand description
Set the command timeout for the current thread.
When set, all commands executed via run() on this thread will be killed if they
exceed the specified duration. Set to None to disable timeout.
This is typically called at the start of a Rayon worker task to apply timeout to all git operations within that task.